<?php
// $Id: definitions.install, v 0.1, 2011/02/24 13:57:32, admin Exp $

/**
 * @file
 *
 * Administration file for the definitions module.
 */


/**
 *
 */
function definitions_page() {
  $definitions = definitions_load_mutiple();

  if (empty($definitions)) {
    return t('There are no definitions yet. Click !link to add one.', array('!link' => l(t('here'), 'admin/content/definitions/add')));
  }

  $rows = array();
  foreach ($definitions as $did => $definition) {
    $curr_first_character = drupal_strtolower(drupal_substr($definition->definition, 0, 1));

    if ($curr_first_character !== $first_character) {
      $first_character = $curr_first_character;
      $rows[$first_character] = array();
    }
    $rows[$first_character][$did] = $definition;
  }
  return theme('definitions_page', $rows);
}

/**
 *
 */
function theme_definitions_page($rows) {

  $output = '<p><a name="top"></a>';
  $occuring_characters = array_keys($rows);

  foreach ($occuring_characters as $i => $character) {
    $capital = drupal_strtoupper($character);
    $output .= (in_array($character, $occuring_characters) ? l($capital, $_GET['q'], array('fragment' => $character)) : $capital);
    $output .= $i < count($occuring_characters) - 1 ? ' | ' : '';
  }

  foreach ($rows as $character => $definitions) {
    $output .= '<h2 name="' . $character . '" id="' . $character . '">' . drupal_strtoupper($character) . '</h2>';
    $output .= '<dl>';

    foreach ($definitions as $did => $definition) {
      $output .= '<dt id="' . $definition->definition . '">' . l($definition->definition, 'admin/content/definitions/' . $did . '/edit') . '</dt>';
      $output .= '<dd>' . $definition->explanation . '</dd>';
    }

    $output .= '</dl>';
    $output .= '<p><sub>' . l(t('Back to Top'), $_GET['q'], array('fragment' => 'top')) . '</sub></p>';
  }
  return $output;
}

/**
 *
 */
function definitions_form($form_state, $definition = NULL) {
  $form = array('definition' => array('#tree' => TRUE));

  $form['definition']['did'] = array(
    '#type' => 'value',
    '#value' => ($definition ? $definition->did : NULL),
  );
  $form['definition']['definition'] = array(
    '#type' => 'textfield',
    '#title' => t('Definition'),
    '#default_value' => ($definition ? $definition->definition : ''),
    '#description' => t(''),
    '#required' => TRUE,
  );
  $form['definition']['explanation'] = array(
    '#type' => 'textarea',
    '#title' => t('Explanation'),
    '#default_value' => ($definition ? $definition->explanation : ''),
    '#description' => t(''),
    '#required' => TRUE,
  );
  $form['definition']['extra_class'] = array(
    '#type' => 'textfield',
    '#title' => t('Extra class'),
    '#default_value' => ($definition ? $definition->extra_class : ''),
    '#description' => t(''),
  );
  $form['submit'] = array('#type' => 'submit', '#value' => t('Submit'));
  $form['delete'] = array('#type' => 'submit', '#value' => t('Delete'));

  return $form;
}

/**
 * Submit callback for the definitions form.
 */
function definitions_form_validate($form, &$form_state) {
  $definition = (object) $form_state['values']['definition'];

  if ($form_state['values']['op'] == t('Delete')) {
    drupal_goto('admin/content/definitions/' .   $definition->did . '/delete', drupal_get_destination())  ;
  }
  elseif (definition_exists($definition)) {
    form_set_error('definition][definition', t('This definition already exists!'));
  }
}

/**
 * Submit callback for the definitions form.
 */
function definitions_form_submit($form, &$form_state) {
  definition_save((object) $form_state['values']['definition']);
  $form_state['redirect'] = 'admin/content/definitions';
}


/**
 * Form defenition for deleting a definition.
 */
function definitions_delete_form(&$form_state, $definition) {
  $form['did'] = array('#type' => 'value', '#value' => $definition->did);
  $form['definition'] = array('#type' => 'value', '#value' => $definition->definition);
  $destination = (isset($_GET['destination']) ? $_GET['destination'] : 'admin/content/definitions');
  return confirm_form($form, t('Are you sure you want to delete the definition %definition', array('%definition' => $definition->definition)), $destination, t('This action cannot be undone.'), t('Delete'), t('Cancel'));
}

/**
 * Submit callback for definitions_delete_form().
 */
function definitions_delete_form_submit($form, &$form_state) {
  db_query("DELETE FROM {definitions} WHERE did = %d", $form_state['values']['did']);
  $form_state['redirect'] = 'admin/content/definitions';
  drupal_set_message(t('The definition %definition has been deleted', array('%definition' => $form_state['values']['definition'])));
}
